// -*- C++ -*-
#include "tao/Services_Activate.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Services_Activate::~TAO_Services_Activate ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
